==> apache-camel-2.18.5-src.zip: apache-camel-2.18.5/components/camel-splunk/src/test/java/org/apache/camel/component/splunk/SplunkMockTestSupport.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.splunk;

import java.net.Socket;

import com.splunk.Service;
import org.apache.camel.CamelContext;
import org.apache.camel.test.junit4.CamelTestSupport;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;

import static org.mockito.Mockito.reset;

public abstract class SplunkMockTestSupport extends CamelTestSupport {

    @Mock
    Service service;

    @Mock
    Socket socket;

    @Override
    protected CamelContext createCamelContext() throws Exception {
        CamelContext context = super.createCamelContext();

        // set splunk to use mocked connection factory
        MockitoAnnotations.initMocks(this);
        reset(service);
        reset(socket);
        SplunkComponent splunk = context.getComponent("splunk", SplunkComponent.class);
        DefaultSplunkConfigurationFactory cf = Helper.mockComponent(service, socket);
        splunk.setSplunkConfigurationFactory(cf);

        return context;
    }

}

==> apache-camel-2.21.0-src.zip: apache-camel-2.21.0/components/camel-splunk/src/test/java/org/apache/camel/component/splunk/SplunkMockTestSupport.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.splunk;

import java.net.Socket;

import com.splunk.Service;
import org.apache.camel.CamelContext;
import org.apache.camel.test.junit4.CamelTestSupport;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

@RunWith(MockitoJUnitRunner.class)
public abstract class SplunkMockTestSupport extends CamelTestSupport {

    @Mock
    Service service;

    @Mock
    Socket socket;

    @Override
    protected CamelContext createCamelContext() throws Exception {
        CamelContext context = super.createCamelContext();

        // set splunk to use mocked connection factory
        SplunkComponent splunk = context.getComponent("splunk", SplunkComponent.class);
        DefaultSplunkConfigurationFactory cf = Helper.mockComponent(service, socket);
        splunk.setSplunkConfigurationFactory(cf);

        return context;
    }

}
